"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const http = __importStar(require("http"));
const https = __importStar(require("https"));
class Client {
    constructor(connection) {
        this.connection = connection;
    }
    _preCall(method, params) {
        const payload = {
            method: method,
            params: params || [],
            id: 1,
            jsonrpc: '2.0'
        };
        const body = JSON.stringify(payload);
        let options = {
            host: this.connection.host,
            port: this.connection.port,
            method: "POST",
            key: this.connection.key,
            cert: this.connection.cert,
            agent: this.connection.agent,
            pfx: this.connection.pfx,
            passphrase: this.connection.passphrase,
            ca: this.connection.ca,
            ciphers: this.connection.ciphers,
            rejectUnauthorized: this.connection.rejectUnauthorized,
            secureProtocol: this.connection.secureProtocol,
            servername: this.connection.servername,
            headers: {
                'Content-Type': 'application/json',
                'Content-Length': Buffer.byteLength(body, 'utf8'),
                host: this.connection.host
            }
        };
        if (this.connection.user && this.connection.pass) {
            options.auth = this.connection.user + ":" + this.connection.pass;
        }
        return { payload, options };
    }
    _call(method, params, callback) {
        let request;
        const { payload, options } = this._preCall(method, params);
        if (this.connection.protocol === 'https')
            request = https.request(options);
        else
            request = http.request(options);
        request.write(JSON.stringify(payload));
        request.on('error', (error) => {
            callback(error);
        });
        request.on('response', (response) => {
            let data = '';
            response.on('data', (chunk) => {
                data += chunk;
            });
            response.on('end', () => {
                if (response.statusCode === 200) {
                    const json = JSON.parse(data);
                    return callback(undefined, json.result);
                }
                else if (response.headers['content-type'] === "application/json") {
                    const json = JSON.parse(data);
                    return callback(json.error);
                }
                else if (response.statusCode === 401) {
                    return callback(new Error('Unauthorized'));
                }
                else {
                    return callback(undefined, data);
                }
            });
        });
        request.end();
    }
    /**
     * @async call a multichain rpc method
     * @param method multichain rpc method to call
     * @param params an array of parameter
     */
    call(method, params = []) {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                this._call(method, params, (error, result) => {
                    if (error)
                        return reject(error);
                    else
                        return resolve(result);
                });
            });
        });
    }
    /**
     * Returns a list of values of this blockchain’s parameters.
     * @param displayName set whether parameters are shown with display names (with hyphens) or canonical names (without hyphens).
     * @param withUpgrade set whether to show the chain’s latest parameters (after any upgrades) or its original parameters (in the genesis block). Note that as of MultiChain 1.0.1, only the protocol version can be upgraded.
     * @returns Return as IBlockchainParamsDisplayName if displayName is true or as IBlockchainParams if false
     */
    getblockchainparams(displayName = true, withUpgrade = true) {
        return __awaiter(this, void 0, void 0, function* () {
            let result = yield this.call('getblockchainparams', [displayName, withUpgrade]);
            return (displayName) ? result : result;
        });
    }
    /**
     * Available in MultiChain Enterprise only.
     * Retrieves a health check for the node.
     * This command can be sent on the regular JSON-RPC API port or on a separate health checking port that will respond even if all main API threads are busy –
     * @see healthcheckport
     */
    gethealthcheck() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('gethealthcheck');
        });
    }
    /**
     * Returns a selection of this node’s runtime parameters, which are set when the node starts up.
     * Some parameters can be modified while MultiChain is running using setruntimeparam.
     */
    getruntimeparams() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getruntimeparams');
        });
    }
    /**
     * Sets the runtime parameter param to value and immediately applies the change.
     * Use the `storeruntimeparams` runtime parameter to persistently store these changes for future launches of MultiChain.
     * @param param the parameter to set
     * @param value the new value
     * @see [MultiChain runtime parameters](https://www.multichain.com/developers/runtime-parameters/)
     */
    setruntimeparam(param, value) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('setruntimeparam', [param, value]);
        });
    }
    /**
     * Returns general information about this node and blockchain.
     * MultiChain adds some fields to Bitcoin Core’s response, giving the blockchain’s chainname, description, protocol, peer-to-peer port.
     * There are also incomingpaused and miningpaused fields – see the pause command.
     * The burnaddress is an address with no known private key, to which assets can be sent to make them provably unspendable.
     * The nodeaddress can be passed to other nodes for connecting.
     * The setupblocks field gives the length in blocks of the setup phase in which some consensus constraints are not applied.
     */
    getinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getinfo');
        });
    }
    /**
     * Returns information about the node’s initialization status, during its initial connection to a new blockchain.
     * This is relevant if the retryinittime runtime parameter is used.
     */
    getinitstatus() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getinitstatus');
        });
    }
    /**
     * Returns a list of available API commands, including MultiChain-specific commands.
     * @param command Optional, help about a specific command
     */
    help(command) {
        return __awaiter(this, void 0, void 0, function* () {
            let params = (command) ? [command] : undefined;
            return yield this.call('help', params);
        });
    }
    /**
     * Shuts down the this blockchain node, i.e. stops the multichaind process.
     */
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('stop');
        });
    }
    /**
     * Creates a pay-to-scripthash (P2SH) multisig address and adds it to the wallet.
     * Funds sent to this address can only be spent by transactions signed by nrequired of the specified keys.
     * Each key can be a full public key, or an address if the corresponding key is in the node’s wallet.
     * (Public keys for a wallet’s addresses can be obtained using the getaddresses call with verbose=true.)
     * @param nrequired The number of required signatures out of the n keys or addresses.
     * @param addresses A JSON array of addresses or hex-encoded public keys
     * @param account Optional, An account to assign the addresses to.
     * @returns the P2SH address.
     */
    addmultisigaddress(nrequired, addresses, account) {
        return __awaiter(this, void 0, void 0, function* () {
            let params = [nrequired, addresses];
            if (account)
                params.push(account);
            return yield this.call('addmultisigaddress', params);
        });
    }
    /**
     * Returns a list of addresses in this node’s wallet.
     * Set verbose to true to get more information about each address, formatted like the output of the validateaddress command.
     * For more control see the new listaddresses command.
     */
    getaddresses(verbose = false) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.call('getaddresses', [verbose]);
            return (verbose) ? result : result;
        });
    }
    /**
     * Returns a new address whose private key is added to the wallet.
     */
    getnewaddress() {
        return __awaiter(this, void 0, void 0, function* () {
            return (yield this.call('getnewaddress'));
        });
    }
    /**
     * Adds address (or an array of addresses) to the wallet, without an associated private key.
     * This creates one or more watch-only addresses, whose activity and balance can be retrieved via various APIs (e.g. with the includeWatchOnly parameter), but whose funds cannot be spent by this node.
     * The rescan parameter controls whether and how the blockchain is rescanned for transactions relating to all wallet addresses, including these new ones.
     * Pass true to rescan the entire chain, false to skip rescanning, and from version 1.0.5, a positive integer to rescan from that block number or a negative integer to rescan that many recent blocks.
     * @returns Returns null if successful.
     */
    importaddress(address, label = '', rescan = true) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('importaddress', [address, label, rescan]);
        });
    }
    /**
     * Returns information about the addresses in the wallet.
     * Provide one or more addresses (comma-delimited or as an array) to retrieve information about specific addresses only, or use * for all addresses in the wallet.
     * Use count and start to retrieve part of the list only, with negative start values (like the default) indicating the most recently created addresses
     */
    listaddresses(addresses, verbose, count, start) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.call('listaddresses', [addresses, verbose, count, start]);
            return (verbose) ? result : result;
        });
    }
    /**
     * Generates one or more public/private key pairs, which are not stored in the wallet or drawn from the node’s key pool, ready for external key management.
     * For each key pair, the address, pubkey (as embedded in transaction inputs) and privkey (used for signatures) is provided.
     */
    createkeypairs(count = 1) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createkeypairs', [count]);
        });
    }
    /**
     * Creates a pay-to-scripthash (P2SH) multisig address.
     * Funds sent to this address can only be spent by transactions signed by nrequired of the specified keys.
     * Each key can be a full hexadecimal public key, or an address if the corresponding key is in the node’s wallet.
     * @returns an object containing the P2SH address and corresponding redeem script.
     */
    createmultisig(nrequired, addresses) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createmultisig', [nrequired, addresses]);
        });
    }
    /**
     * Returns information about address, or the address corresponding to the specified privkey private key or pubkey public key, including whether this node has the address’s private key in its wallet.
     */
    validateaddress(address) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('validateaddress', [address]);
        });
    }
    /**
     * Grants permissions to addresses, a comma-separated list of addresses.
     * For global permissions, set permissions to one of connect, send, receive, create, issue, mine, activate, admin, or a comma-separated list thereof.
     * Use mine with caution – if too many addresses with mine permissions become inactive, your chain could become stuck (see mining-diversity blockchain parameter).
     * For per-asset, per-stream, per-variable and per-library permissions, use the form entity.permission or entity.permission,permission,... where entity is the entity name, ref or creation txid and each permission is a relevant permission for that entity type.
     * Relevant permissions are issue,send,receive,activate,admin for assets, write,read,activate,admin for streams and write,activate,admin for variables and libraries.
     * (Each grant command can only assign global permissions, or permissions for a single entity.)
     * If the chain uses a native currency, you can send some to each recipient using the native-amount parameter.
     * @param addresses List of addresses to send to
     * @param permission List of permission to grant
     * @param nativeAmount Native currency amount to send. eg 0.1. Default - 0.0
     * @param startBlock Block to apply permissions from (inclusive). Default - 0
     * @param endBlock Block to apply permissions to (exclusive). Default - 4294967295
     * @param comment
     * @param commentTo
     * @returns the txid of the grant transaction sent.
     * @see [MultiChain permissions management](https://www.multichain.com/developers/permissions-management/)
     */
    grant(addresses, permission, nativeAmount, startBlock, endBlock, comment, commentTo) {
        return __awaiter(this, void 0, void 0, function* () {
            const permissions = [];
            for (let i = 0; i < permission.length; i++) {
                if (typeof (permission[i]) === 'string') {
                    permissions.push(permission[i]);
                }
                else {
                    const perm = permission[i];
                    permissions.push(perm.identifier + '.' + perm.permission);
                }
            }
            return yield this.call('grant', [addresses.join(','), permissions.join(','), nativeAmount || 0, startBlock || 0, endBlock || -1, comment, commentTo]);
        });
    }
    /**
     *
     */
    grantfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('grantfrom');
        });
    }
    /**
     *
     */
    grantwithdata() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('grantwithdata');
        });
    }
    /**
     *
     */
    grantwithdatafrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('grantwithdatafrom');
        });
    }
    /**
     *
     */
    listpermissions() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listpermissions');
        });
    }
    /**
     *
     */
    revoke() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('revoke');
        });
    }
    /**
     *
     */
    revokefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('revokefrom');
        });
    }
    /**
     *
     */
    verifypermission() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('verifypermission');
        });
    }
    /**
     *
     */
    getassetinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getassetinfo');
        });
    }
    /**
     *
     */
    gettokeninfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('gettokeninfo');
        });
    }
    /**
     *
     */
    issue() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('issue');
        });
    }
    /**
     *
     */
    issuefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('issuefrom');
        });
    }
    /**
     *
     */
    issuemore() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('issuemore');
        });
    }
    /**
     *
     */
    issuemorefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('issuemorefrom');
        });
    }
    /**
     *
     */
    issuetoken() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('issuetoken');
        });
    }
    /**
     *
     */
    issuetokenfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('issuetokenfrom');
        });
    }
    /**
     *
     */
    listassetissues() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listassetissues');
        });
    }
    /**
     *
     */
    listassets() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listassets');
        });
    }
    /**
     *
     */
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('update');
        });
    }
    /**
     *
     */
    updatefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('updatefrom');
        });
    }
    /**
     *
     */
    getaddressbalances() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getaddressbalances');
        });
    }
    /**
     *
     */
    getaddresstransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getaddresstransaction');
        });
    }
    /**
     *
     */
    getmultibalances() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getmultibalances');
        });
    }
    /**
     *
     */
    gettokenbalances() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('gettokenbalances');
        });
    }
    /**
     *
     */
    gettotalbalances() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('gettotalbalances');
        });
    }
    /**
     *
     */
    getwallettransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getwallettransaction');
        });
    }
    /**
     *
     */
    listaddresstransactions() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listaddresstransactions');
        });
    }
    /**
     *
     */
    listwallettransactions() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listwallettransactions');
        });
    }
    /**
     *
     */
    send() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('send');
        });
    }
    /**
     *
     */
    sendasset() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('sendasset');
        });
    }
    /**
     *
     */
    sendassetfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('sendassetfrom');
        });
    }
    /**
     *
     */
    sendfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('sendfrom');
        });
    }
    /**
     *
     */
    sendwithdata() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('sendwithdata');
        });
    }
    /**
     *
     */
    sendwithdatafrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('sendwithdatafrom');
        });
    }
    /**
     *
     */
    appendrawexchange() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('appendrawexchange');
        });
    }
    /**
     *
     */
    completerawexchange() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('completerawexchange');
        });
    }
    /**
     *
     */
    createrawexchange() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createrawexchange');
        });
    }
    /**
     *
     */
    decoderawexchange() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('decoderawexchange');
        });
    }
    /**
     *
     */
    disablerawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('disablerawtransaction');
        });
    }
    /**
     *
     */
    preparelockunspent() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('preparelockunspent');
        });
    }
    /**
     *
     */
    preparelockunspentfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('preparelockunspentfrom');
        });
    }
    /**
     *
     */
    create() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('create');
        });
    }
    /**
     *
     */
    createfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createfrom');
        });
    }
    /**
     *
     */
    getstreaminfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getstreaminfo');
        });
    }
    /**
     *
     */
    liststreams() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreams');
        });
    }
    /**
     *
     */
    publish() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('publish');
        });
    }
    /**
     *
     */
    publishfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('publishfrom');
        });
    }
    /**
     *
     */
    publishmulti() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('publishmulti');
        });
    }
    /**
     *
     */
    publishmultifrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('publishmultifrom');
        });
    }
    /**
     *
     */
    subscribe() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('subscribe');
        });
    }
    /**
     *
     */
    trimsubscribe() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('trimsubscribe');
        });
    }
    /**
     *
     */
    unsubscribe() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('unsubscribe');
        });
    }
    /**
     *
     */
    getassettransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getassettransaction');
        });
    }
    /**
     *
     */
    listassettransactions() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listassettransactions');
        });
    }
    /**
     *
     */
    getstreamitem() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getstreamitem');
        });
    }
    /**
     *
     */
    getstreamkeysummary() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getstreamkeysummary');
        });
    }
    /**
     *
     */
    getstreampublishersummary() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getstreampublishersummary');
        });
    }
    /**
     *
     */
    gettxoutdata() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('gettxoutdata');
        });
    }
    /**
     *
     */
    liststreamblockitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamblockitems');
        });
    }
    /**
     *
     */
    liststreamkeyitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamkeyitems');
        });
    }
    /**
     *
     */
    liststreamkeys() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamkeys');
        });
    }
    /**
     *
     */
    liststreamitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamitems');
        });
    }
    /**
     *
     */
    liststreampublisheritems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreampublisheritems');
        });
    }
    /**
     *
     */
    liststreampublishers() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreampublishers');
        });
    }
    /**
     *
     */
    liststreamqueryitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamqueryitems');
        });
    }
    /**
     *
     */
    liststreamtxitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamtxitems');
        });
    }
    /**
     *
     */
    purgepublisheditems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('purgepublisheditems');
        });
    }
    /**
     *
     */
    purgestreamitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('purgestreamitems');
        });
    }
    /**
     *
     */
    retrievestreamitems() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('retrievestreamitems');
        });
    }
    /**
     *
     */
    combineunspent() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('combineunspent');
        });
    }
    /**
     *
     */
    listlockunspent() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listlockunspent');
        });
    }
    /**
     *
     */
    listunspent() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listunspent');
        });
    }
    /**
     *
     */
    lockunspent() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('lockunspent');
        });
    }
    /**
     *
     */
    appendrawchange() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('appendrawchange');
        });
    }
    /**
     *
     */
    appendrawdata() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('appendrawdata');
        });
    }
    /**
     *
     */
    appendrawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('appendrawtransaction');
        });
    }
    /**
     *
     */
    createrawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createrawtransaction');
        });
    }
    /**
     *
     */
    createrawsendfrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createrawsendfrom');
        });
    }
    /**
     *
     */
    decoderawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('decoderawtransaction');
        });
    }
    /**
     *
     */
    sendrawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('sendrawtransaction');
        });
    }
    /**
     *
     */
    signrawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('signrawtransaction');
        });
    }
    /**
     *
     */
    addnode() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('addnode');
        });
    }
    /**
     *
     */
    getaddednodeinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getaddednodeinfo');
        });
    }
    /**
     *
     */
    getnetworkinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getnetworkinfo');
        });
    }
    /**
     *
     */
    getpeerinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getpeerinfo');
        });
    }
    /**
     *
     */
    liststorednodes() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststorednodes');
        });
    }
    /**
     *
     */
    ping() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('ping');
        });
    }
    /**
     *
     */
    storenode() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('storenode');
        });
    }
    /**
     *
     */
    signmessage() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('signmessage');
        });
    }
    /**
     *
     */
    verifymessage() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('verifymessage');
        });
    }
    /**
     *
     */
    getblock() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getblock');
        });
    }
    /**
     *
     */
    getblockchaininfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getblockchaininfo');
        });
    }
    /**
     *
     */
    getblockhash() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getblockhash');
        });
    }
    /**
     *
     */
    getchaintotals() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getchaintotals');
        });
    }
    /**
     *
     */
    getlastblockinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getlastblockinfo');
        });
    }
    /**
     *
     */
    getmempoolinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getmempoolinfo');
        });
    }
    /**
     *
     */
    getrawmempool() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getrawmempool');
        });
    }
    /**
     *
     */
    getrawtransaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getrawtransaction');
        });
    }
    /**
     *
     */
    gettxout() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('gettxout');
        });
    }
    /**
     *
     */
    listblocks() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listblocks');
        });
    }
    /**
     *
     */
    listminers() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listminers');
        });
    }
    /**
     *
     */
    createbinarycache() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createbinarycache');
        });
    }
    /**
     *
     */
    appendbinarycache() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('appendbinarycache');
        });
    }
    /**
     *
     */
    deletebinarycache() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('deletebinarycache');
        });
    }
    /**
     *
     */
    txouttobinarycache() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('txouttobinarycache');
        });
    }
    /**
     *
     */
    backupwallet() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('backupwallet');
        });
    }
    /**
     *
     */
    dumpprivkey() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('dumpprivkey');
        });
    }
    /**
     *
     */
    dumpwallet() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('dumpwallet');
        });
    }
    /**
     *
     */
    encryptwallet() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('encryptwallet');
        });
    }
    /**
     *
     */
    getwalletinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getwalletinfo');
        });
    }
    /**
     *
     */
    importprivkey() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('importprivkey');
        });
    }
    /**
     *
     */
    importwallet() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('importwallet');
        });
    }
    /**
     *
     */
    walletlock() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('walletlock');
        });
    }
    /**
     *
     */
    walletpassphrase() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('walletpassphrase');
        });
    }
    /**
     *
     */
    walletpassphrasechange() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('walletpassphrasechange');
        });
    }
    /**
     *
     */
    addtofeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('addtofeed');
        });
    }
    /**
     *
     */
    createfeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('createfeed');
        });
    }
    /**
     *
     */
    datareftobinarycache() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('datareftobinarycache');
        });
    }
    /**
     *
     */
    deletefeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('deletefeed');
        });
    }
    /**
     *
     */
    getdatarefdata() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getdatarefdata');
        });
    }
    /**
     *
     */
    listfeeds() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listfeeds');
        });
    }
    /**
     *
     */
    pausefeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('pausefeed');
        });
    }
    /**
     *
     */
    purgefeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('purgefeed');
        });
    }
    /**
     *
     */
    resumefeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('resumefeed');
        });
    }
    /**
     *
     */
    updatefeed() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('updatefeed');
        });
    }
    /**
     *
     */
    approvefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('approvefrom');
        });
    }
    /**
     *
     */
    getfiltercode() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getfiltercode');
        });
    }
    /**
     *
     */
    liststreamfilters() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('liststreamfilters');
        });
    }
    /**
     *
     */
    listtxfilters() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listtxfilters');
        });
    }
    /**
     *
     */
    listupgrades() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listupgrades');
        });
    }
    /**
     *
     */
    runstreamfilter() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('runstreamfilter');
        });
    }
    /**
     *
     */
    runtxfilter() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('runtxfilter');
        });
    }
    /**
     *
     */
    teststreamfilter() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('teststreamfilter');
        });
    }
    /**
     *
     */
    testtxfilter() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('testtxfilter');
        });
    }
    /**
     *
     */
    addlibraryupdate() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('addlibraryupdate');
        });
    }
    /**
     *
     */
    addlibraryupdatefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('addlibraryupdatefrom');
        });
    }
    /**
     *
     */
    getlibrarycode() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getlibrarycode');
        });
    }
    /**
     *
     */
    getvariablehistory() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getvariablehistory');
        });
    }
    /**
     *
     */
    getvariableinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getvariableinfo');
        });
    }
    /**
     *
     */
    getvariablevalue() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getvariablevalue');
        });
    }
    /**
     *
     */
    listlibraries() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listlibraries');
        });
    }
    /**
     *
     */
    setvariablevalue() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('setvariablevalue');
        });
    }
    /**
     *
     */
    setvariablevaluefrom() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('setvariablevaluefrom');
        });
    }
    /**
     *
     */
    testlibrary() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('testlibrary');
        });
    }
    /**
     *
     */
    clearmempool() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('clearmempool');
        });
    }
    /**
     *
     */
    getchunkqueueinfo() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getchunkqueueinfo');
        });
    }
    /**
     *
     */
    getchunkqueuetotals() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getchunkqueuetotals');
        });
    }
    /**
     *
     */
    pause() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('pause');
        });
    }
    /**
     *
     */
    resume() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('resume');
        });
    }
    /**
     *
     */
    setlastblock() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('setlastblock');
        });
    }
    /**
     *
     */
    getlicenserequest() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('getlicenserequest');
        });
    }
    /**
     *
     */
    activatelicense() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('activatelicense');
        });
    }
    /**
     *
     */
    listlicenses() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('listlicenses');
        });
    }
    /**
     *
     */
    transferlicense() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.call('transferlicense');
        });
    }
}
exports.default = Client;
//# sourceMappingURL=client.js.map